'use strict'
var __importDefault =
	(this && this.__importDefault) ||
	function (mod) {
		return mod && mod.__esModule ? mod : { default: mod }
	}
Object.defineProperty(exports, '__esModule', { value: true })
// Import caterpillar [Caterpillar](https://github.com/bevry/caterpillar) for logging
const caterpillar_1 = require('caterpillar')
const caterpillar_filter_1 = __importDefault(require('caterpillar-filter'))
const caterpillar_human_1 = __importDefault(require('caterpillar-human'))
// Import the package used to get the value of CLI arguments
const get_cli_arg_1 = __importDefault(require('get-cli-arg'))
// Import out projectz utility
const index_js_1 = require('./index.js')
async function main() {
	// Compile
	if (process.argv.includes('compile')) {
		// fetch
		const p = get_cli_arg_1.default('path')
		const d = get_cli_arg_1.default('verbose')
		// bc upgrade
		if (process.argv.includes('-p')) {
			console.log(
				'projecz now requires -p argument to be specifie via --path=value'
			)
			return process.exit(1)
		}
		if (process.argv.includes('-d')) {
			console.log(
				'projecz now requires -d argument to be specifie via --verbose'
			)
			return process.exit(1)
		}
		// Prepare our logging configuration
		const level = d ? 7 : 6
		// Setup our logging
		const logger = new caterpillar_1.Logger({ level })
		const filter = new caterpillar_filter_1.default()
		const human = new caterpillar_human_1.default()
		// Pipe logger output to filter, then filter output to stdout
		logger.pipe(filter).pipe(human).pipe(process.stdout)
		// Compile
		try {
			const project = new index_js_1.Projectz({
				log: logger.log.bind(logger),
				cwd: p || null,
			})
			await project.compile()
		} catch (err) {
			// error
			logger.log('err', err.stack)
			return process.exit(1)
		}
		// Done
		logger.log('info', 'Completed successfully')
	} else {
		// output help
		console.log(
			'projectz compile: merge our data files and compile our meta files'
		)
		console.log('\t--verbose\tOutputs verbose logging')
		console.log(
			'\t--path=value\tPath to the project that you wish to work with, defaults to the current working directory'
		)
		return process.exit(1)
	}
}
main()
